@@ -442,7 +442,7 @@ def test_make_binary_trigger_cutoff():
     input_array = rng.standard_normal((100, 100))
     result = make_binary(input_array, numotsu=100)
     frac = np.sum(result) / result.size
-    assert frac > 1e-3
+    assert frac >= 1e-3
 
 
 def test_do_hough(numpy_array):
@@ -458,13 +458,14 @@ def test_do_hough(numpy_array):
     width, height = binary.shape
     diag_len = np.ceil(np.sqrt(width * width + height * height))  # max_dist
     diag_len = int(diag_len)
-    rhos = np.linspace(-diag_len, diag_len, int(diag_len * 2.0))
+    num_rhos = 2 * diag_len + 1
+    rhos = np.linspace(-diag_len, diag_len, num_rhos)
     # Cache some reusable values
     cos_t = np.cos(thetas)
     sin_t = np.sin(thetas)
     num_thetas = len(thetas)
     # Hough accumulator array of theta vs rho
-    accumulator = np.zeros((2 * diag_len, num_thetas), dtype=np.uint64)
+    accumulator = np.zeros((num_rhos, num_thetas), dtype=np.uint64)
     y_idxs, x_idxs = np.nonzero(binary)  # (row, col) indexes to edges
     for i in range(len(x_idxs)):
         x = x_idxs[i]
